@@ -55,9 +55,9 @@ cat(es[2]," (",es[1],",",es[3],")\n\n",sep="")
 if(x$Model == "ROY"){
 
 
-es <- format(x$res, digits = 3, trim=TRUE)
+es <- format(x$res, digits = 3, trim = TRUE)
 
-cat("\nMarginal effect with ",(1-x$prob.lev)*100,"% interval:\n\n",sep="")
+cat("\nAverage treatment effect with ",(1-x$prob.lev)*100,"% interval:\n\n",sep="")
 cat(es[2]," (",es[1],",",es[3],")\n\n",sep="")
 
 
